import { InputEditor } from "./InputEditor";
import { DataView } from "../DataView";
import { IDataViewItem } from "../types";
export declare function getEditor(item: IDataViewItem, dataView: DataView): InputEditor;
