declare const _default: {
    popups: {};
    lastActive: any;
    freeCount: number;
    add(id: string, popup: any): void;
    setActive(id: string): void;
    openFreeWindow(node: HTMLElement): void;
    closeFreeWindow(node: HTMLElement): void;
};
export default _default;
