import { ILayoutState, IRendererConfig, Split } from "./../types";
export declare function getFixedColsHeader(renderConfig: IRendererConfig, layout: ILayoutState, mode: Split.left | Split.right): any;
export declare function getFixedCols(renderConfig: IRendererConfig, layout: ILayoutState, mode: Split.left | Split.right, source?: Split.top | Split.bottom): any[];
